@@ -55,10 +55,9 @@ class GitIssuePublisher(Publisher):
             title = f"Automated Issue on branch {self.branch}"
             repo = self.__get_repo()
             existing_issue = self.thread(title)
+            existing_issue.create_comment(body)
 
-            repo.create_issue_comment(existing_issue.number, body)
-
-            return existing_issue
+            return 
         except GithubException as e:
             print(f"Error publishing issue: {e}")
             raise
@@ -73,20 +72,23 @@ class GitIssuePublisher(Publisher):
         """
         try:
             repo = self.__get_repo()
-            issues = repo.get_issues(state='all')  # Fetch all issues (open and closed)
 
+            ############################################################################
             # Search for the issue by title
+            # Esta parte del codigo es la mas costosa... investigar como optimizar
+            issues = repo.get_issues(state='all')  # Fetch all issues (open and closed)
             existing_issue = None
-            for issue in issues:
+            for issue in issues: 
                 if issue.title == title:
                     existing_issue = issue
                     break
+            ############################################################################
 
             # Check if the issue is found
             if existing_issue:
                 if existing_issue.state != 'open':
                     existing_issue.edit(state='open')
-                existing_issue.edit(assignee=self.user)
+                existing_issue.add_to_assignees(assignee=self.user)
                 return existing_issue
 
             # If no issue is found, create a new one
